@@ -71,9 +71,9 @@ new_gkdb (void) {
  *
  * On error, NULL is returned.
  * On success, the string module value is returned. */
-char *
+const char *
 get_mtr_type_str (GSMetricType type) {
-  GEnum enum_metric_types[] = {
+  static const GEnum enum_metric_types[] = {
     {"II32", MTRC_TYPE_II32},
     {"IS32", MTRC_TYPE_IS32},
     {"IU64", MTRC_TYPE_IU64},
@@ -541,7 +541,7 @@ const GKHashMetric app_metrics[] = {
   { .metric.dbm=MTRC_DB_PROPS    , MTRC_TYPE_SI32 , new_si32_ht , des_si32_free , del_si32_free , 1 , NULL , "SI32_DB_PROPS.db"    } ,
 };
 
-size_t app_metrics_len = ARRAY_SIZE (app_metrics);
+const size_t app_metrics_len = ARRAY_SIZE (app_metrics);
 /* *INDENT-ON* */
 
 /* Destroys malloc'd module metrics */
@@ -623,7 +623,7 @@ init_gkhashdb (void) {
  * On error, -1 is returned.
  * On success 0 is returned */
 int
-ins_iglp (khash_t (iglp) *hash, uint64_t key, GLastParse lp) {
+ins_iglp (khash_t (iglp) *hash, uint64_t key, const GLastParse *lp) {
   khint_t k;
   int ret;
 
@@ -634,7 +634,7 @@ ins_iglp (khash_t (iglp) *hash, uint64_t key, GLastParse lp) {
   if (ret == -1)
     return -1;
 
-  kh_val (hash, k) = lp;
+  kh_val (hash, k) = *lp;
 
   return 0;
 }
@@ -1040,8 +1040,10 @@ inc_su64 (khash_t (su64) *hash, const char *key, uint64_t inc) {
     dupkey = xstrdup (key);
     k = kh_put (su64, hash, dupkey, &ret);
     /* operation failed */
-    if (ret == -1)
+    if (ret == -1) {
+      free (dupkey);
       return -1;
+    }
   } else {
     value = kh_val (hash, k) + inc;
   }
@@ -1087,6 +1089,7 @@ static uint32_t
 inc_si32 (khash_t (si32) *hash, const char *key, uint32_t inc) {
   khint_t k;
   int ret;
+  char *dupkey = NULL;
 
   if (!hash)
     return 0;
@@ -1094,10 +1097,16 @@ inc_si32 (khash_t (si32) *hash, const char *key, uint32_t inc) {
   k = kh_get (si32, hash, key);
   /* key not found, put a new hash with val=0 */
   if (k == kh_end (hash)) {
-    k = kh_put (si32, hash, key, &ret);
+    dupkey = xstrdup (key);
+    k = kh_put (si32, hash, dupkey, &ret);
     /* operation failed */
-    if (ret == -1)
+    if (ret == -1) {
+      free (dupkey);
       return 0;
+    }
+    /* concurrently added */
+    if (ret == 0)
+      free (dupkey);
     kh_val (hash, k) = 0;
   }
 
@@ -1363,7 +1372,7 @@ get_iglp (khash_t (iglp) *hash, uint64_t key) {
  * and set the maximum and minimum values found on an integer key and
  * integer value.
  *
- * Note: This are expensive calls since it has to iterate over all
+ * Note: These are expensive calls since it has to iterate over all
  * key-value pairs
  *
  * If the hash structure is empty, no values are set.
@@ -1392,7 +1401,7 @@ get_ii32_min_max (khash_t (ii32) *hash, uint32_t *min, uint32_t *max) {
  * and set the maximum and minimum values found on an integer key and
  * a uint64_t value.
  *
- * Note: This are expensive calls since it has to iterate over all
+ * Note: These are expensive calls since it has to iterate over all
  * key-value pairs
  *
  * If the hash structure is empty, no values are set.
@@ -1484,13 +1493,11 @@ ht_inc_cnt_overall (const char *key, uint32_t val) {
   if (!hash)
     return 0;
 
-  if (get_si32 (hash, key) != 0)
-    return inc_si32 (hash, key, val);
-  return inc_si32 (hash, xstrdup (key), val);
+  return inc_si32 (hash, key, val);
 }
 
 int
-ht_insert_last_parse (uint64_t key, GLastParse lp) {
+ht_insert_last_parse (uint64_t key, const GLastParse *lp) {
   GKDB *db = get_db_instance (DB_INSTANCE);
   khash_t (iglp) * hash = get_hdb (db, MTRC_LAST_PARSE);
 
@@ -1509,9 +1516,7 @@ ht_ins_seq (khash_t (si32) *hash, const char *key) {
   if (!hash)
     return 0;
 
-  if (get_si32 (hash, key) != 0)
-    return inc_si32 (hash, key, 1);
-  return inc_si32 (hash, xstrdup (key), 1);
+  return inc_si32 (hash, key, 1);
 }
 
 /* Insert an IP hostname mapped to the corresponding hostname.
