@@ -52,7 +52,7 @@ const GKHashMetric global_metrics[] = {
 };
 
 /* Per module & per date */
-GKHashMetric module_metrics[] = {
+const GKHashMetric module_metrics[] = {
   { .metric.storem=MTRC_KEYMAP    , MTRC_TYPE_II32 , new_ii32_ht , des_ii32      , del_ii32      , 1 , NULL , NULL } ,
   { .metric.storem=MTRC_ROOTMAP   , MTRC_TYPE_IS32 , new_is32_ht , des_is32_free , del_is32_free , 1 , NULL , NULL } ,
   { .metric.storem=MTRC_DATAMAP   , MTRC_TYPE_IS32 , new_is32_ht , des_is32_free , del_is32_free , 1 , NULL , NULL } ,
@@ -68,8 +68,8 @@ GKHashMetric module_metrics[] = {
   { .metric.storem=MTRC_AGENTS    , MTRC_TYPE_IGSL , new_igsl_ht , des_igsl_free , del_igsl_free , 1 , NULL , NULL } ,
   { .metric.storem=MTRC_METADATA  , MTRC_TYPE_SU64 , new_su64_ht , des_su64_free , del_su64_free , 1 , NULL , NULL } ,
 };
-size_t module_metrics_len = ARRAY_SIZE (module_metrics);
-size_t global_metrics_len = ARRAY_SIZE (global_metrics);
+const size_t module_metrics_len = ARRAY_SIZE (module_metrics);
+const size_t global_metrics_len = ARRAY_SIZE (global_metrics);
 /* *INDENT-ON* */
 
 /* Allocate memory for a new store container GKHashStorage instance.
@@ -420,7 +420,7 @@ ht_insert_keymap (GModule module, uint32_t date, uint32_t key, uint32_t *ckey) {
   khash_t (ii32) * cache = get_hash_from_cache (module, MTRC_KEYMAP);
 
   uint32_t val = 0;
-  char *modstr = NULL;
+  const char *modstr;
 
   if (!hash)
     return 0;
@@ -432,11 +432,9 @@ ht_insert_keymap (GModule module, uint32_t date, uint32_t key, uint32_t *ckey) {
 
   modstr = get_module_str (module);
   if ((val = ins_ii32_inc (hash, key, ht_ins_seq, seqs, modstr)) == 0) {
-    free (modstr);
     return val;
   }
   *ckey = ins_ii32_ai (cache, key);
-  free (modstr);
 
   return val;
 }
@@ -447,8 +445,7 @@ ht_insert_keymap (GModule module, uint32_t date, uint32_t key, uint32_t *ckey) {
  * On error, -1 is returned.
  * On success 0 is returned */
 int
-ht_insert_rootmap (GModule module, uint32_t date, uint32_t key, const char *value,
-                   uint32_t ckey) {
+ht_insert_rootmap (GModule module, uint32_t date, uint32_t key, const char *value, uint32_t ckey) {
   khash_t (is32) * hash = get_hash (module, date, MTRC_ROOTMAP);
   khash_t (is32) * cache = get_hash_from_cache (module, MTRC_ROOTMAP);
   char *dupval = NULL;
@@ -471,8 +468,7 @@ ht_insert_rootmap (GModule module, uint32_t date, uint32_t key, const char *valu
  * On error, -1 is returned.
  * On success 0 is returned */
 int
-ht_insert_datamap (GModule module, uint32_t date, uint32_t key, const char *value,
-                   uint32_t ckey) {
+ht_insert_datamap (GModule module, uint32_t date, uint32_t key, const char *value, uint32_t ckey) {
   khash_t (is32) * hash = get_hash (module, date, MTRC_DATAMAP);
   khash_t (is32) * cache = get_hash_from_cache (module, MTRC_DATAMAP);
   char *dupval = NULL;
@@ -614,8 +610,7 @@ ht_insert_maxts (GModule module, uint32_t date, uint32_t key, uint64_t value, ui
  * On error, or if key exists, -1 is returned.
  * On success 0 is returned */
 int
-ht_insert_method (GModule module, uint32_t date, uint32_t key, const char *value,
-                  uint32_t ckey) {
+ht_insert_method (GModule module, uint32_t date, uint32_t key, const char *value, uint32_t ckey) {
   GKDB *db = get_db_instance (DB_INSTANCE);
   khash_t (ii08) * hash = get_hash (module, date, MTRC_METHODS);
   khash_t (ii08) * cache = get_hash_from_cache (module, MTRC_METHODS);
@@ -640,8 +635,7 @@ ht_insert_method (GModule module, uint32_t date, uint32_t key, const char *value
  * On error, or if key exists, -1 is returned.
  * On success 0 is returned */
 int
-ht_insert_protocol (GModule module, uint32_t date, uint32_t key, const char *value,
-                    uint32_t ckey) {
+ht_insert_protocol (GModule module, uint32_t date, uint32_t key, const char *value, uint32_t ckey) {
   GKDB *db = get_db_instance (DB_INSTANCE);
   khash_t (ii08) * hash = get_hash (module, date, MTRC_PROTOCOLS);
   khash_t (ii08) * cache = get_hash_from_cache (module, MTRC_PROTOCOLS);
@@ -1190,8 +1184,7 @@ ins_cache_map (GModule module, GSMetric metric, uint32_t key) {
 }
 
 static int
-ins_cache_ii08 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key,
-                uint32_t ckey) {
+ins_cache_ii08 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key, uint32_t ckey) {
   khash_t (ii08) * hash = get_hash_from_store (store, module, metric);
   khash_t (ii08) * cache = get_hash_from_cache (module, metric);
   khint_t k;
@@ -1202,8 +1195,7 @@ ins_cache_ii08 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t
 }
 
 static int
-ins_cache_is32 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key,
-                uint32_t ckey) {
+ins_cache_is32 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key, uint32_t ckey) {
   khash_t (is32) * hash = get_hash_from_store (store, module, metric);
   khash_t (is32) * cache = get_hash_from_cache (module, metric);
   khint_t k;
@@ -1214,8 +1206,7 @@ ins_cache_is32 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t
 }
 
 static int
-inc_cache_ii32 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key,
-                uint32_t ckey) {
+inc_cache_ii32 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key, uint32_t ckey) {
   khash_t (ii32) * hash = get_hash_from_store (store, module, metric);
   khash_t (ii32) * cache = get_hash_from_cache (module, metric);
   khint_t k;
@@ -1226,8 +1217,7 @@ inc_cache_ii32 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t
 }
 
 static int
-max_cache_iu64 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key,
-                uint32_t ckey) {
+max_cache_iu64 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key, uint32_t ckey) {
   khash_t (iu64) * hash = get_hash_from_store (store, module, metric);
   khash_t (iu64) * cache = get_hash_from_cache (module, metric);
   khint_t k;
@@ -1241,8 +1231,7 @@ max_cache_iu64 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t
 }
 
 static int
-inc_cache_iu64 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key,
-                uint32_t ckey) {
+inc_cache_iu64 (GKHashStorage *store, GModule module, GSMetric metric, uint32_t key, uint32_t ckey) {
   khash_t (iu64) * hash = get_hash_from_store (store, module, metric);
   khash_t (iu64) * cache = get_hash_from_cache (module, metric);
   khint_t k;
@@ -1450,7 +1439,7 @@ parse_raw_data (GModule module) {
 #ifdef _DEBUG
   clock_t begin = clock ();
   double taken;
-  char *modstr = NULL;
+  const char *modstr = NULL;
   LOG_DEBUG (("== parse_raw_data ==\n"));
 #endif
 
@@ -1470,7 +1459,6 @@ parse_raw_data (GModule module) {
   modstr = get_module_str (module);
   taken = (double) (clock () - begin) / CLOCKS_PER_SEC;
   LOG_DEBUG (("== %-30s%f\n\n", modstr, taken));
-  free (modstr);
 #endif
 
   return raw_data;
