@@ -439,13 +439,14 @@ __attribute__((no_sanitize ("unsigned-integer-overflow")))
   __attribute__((no_sanitize ("unsigned-shift-base")))
 #endif
 #endif
-  static kh_inline khint_t __ac_X31_hash_string (const char *s) {
+static kh_inline khint_t
+__ac_X31_hash_string (const char *s) {
   khint_t h = (khint_t) * s;
   if (h)
     for (++s; *s; ++s)
       h = (h << 5) - h + (khint_t) * s;
   return h;
-  }
+}
 
 /*! @function
   @abstract     Another interface to const char* hash function
