@@ -144,16 +144,14 @@ set_glog (Logs *logs, const char *filename) {
     logs->size = newlen;
   }
 
-  fn = xstrdup (filename);      /* ensure fn is a string */
+  fn = xstrdup (filename); /* ensure fn is a string */
   glog = logs->glog;
   glog[logs->idx].errors = xcalloc (MAX_LOG_ERRORS, sizeof (char *));
   glog[logs->idx].props.filename = xstrdup (fn);
   glog[logs->idx].props.fname = xstrdup (basename (fn));
 
   if (!glog->pipe && conf.fname_as_vhost) {
-    if (!
-        (fvh =
-         regex_extract_string (glog[logs->idx].props.fname, conf.fname_as_vhost, 1, &err)))
+    if (!(fvh = regex_extract_string (glog[logs->idx].props.fname, conf.fname_as_vhost, 1, &err)))
       FATAL ("%s %s[%s]", err, glog[logs->idx].props.fname, conf.fname_as_vhost);
     glog[logs->idx].fname_as_vhost = fvh;
   }
@@ -362,14 +360,14 @@ free_glog (GLogItem *logitem) {
 /* Decodes the given URL-encoded string.
  *
  * On success, the decoded string is assigned to the output buffer. */
-#define B16210(x) (((x) >= '0' && (x) <= '9') ? ((x) - '0') : (toupper((x)) - 'A' + 10))
+#define B16210(x) (((x) >= '0' && (x) <= '9') ? ((x) - '0') : (toupper((unsigned char) (x)) - 'A' + 10))
 static void
 decode_hex (char *url, char *out) {
   char *ptr;
   const char *c;
 
   for (c = url, ptr = out; *c; c++) {
-    if (*c != '%' || !isxdigit (c[1]) || !isxdigit (c[2])) {
+    if (*c != '%' || !isxdigit ((unsigned char) c[1]) || !isxdigit ((unsigned char) c[2])) {
       *ptr++ = *c;
     } else {
       *ptr++ = (char) ((B16210 (c[1]) * 16) + (B16210 (c[2])));
@@ -762,7 +760,7 @@ static void
 find_alpha (const char **str) {
   const char *s = *str;
   while (*s) {
-    if (isspace (*s))
+    if (isspace ((unsigned char) *s))
       s++;
     else
       break;
@@ -777,7 +775,7 @@ find_alpha_count (const char *str) {
   int cnt = 0;
   const char *s = str;
   while (*s) {
-    if (isspace (*s))
+    if (isspace ((unsigned char) *s))
       s++, cnt++;
     else
       break;
@@ -1134,7 +1132,7 @@ parse_specifier (GLogItem *logitem, const char **str, const char *p, const char
     if (tkn == bEnd || *bEnd != '\0' || errno == ERANGE)
       bandw = 0;
     logitem->resp_size = bandw;
-    __sync_bool_compare_and_swap (&conf.bandwidth, 0, 1);       /* set flag */
+    __sync_bool_compare_and_swap (&conf.bandwidth, 0, 1); /* set flag */
     free (tkn);
     break;
     /* referrer */
@@ -1203,7 +1201,7 @@ parse_specifier (GLogItem *logitem, const char **str, const char *p, const char
     logitem->serve_time = (serve_secs > 0) ? serve_secs * MILS : 0;
 
     /* Determine if time-served data was stored on-disk. */
-    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1);     /* set flag */
+    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1); /* set flag */
     free (tkn);
     break;
     /* time taken to serve the request, in seconds with a milliseconds
@@ -1226,7 +1224,7 @@ parse_specifier (GLogItem *logitem, const char **str, const char *p, const char
     logitem->serve_time = (serve_secs > 0) ? serve_secs * SECS : 0;
 
     /* Determine if time-served data was stored on-disk. */
-    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1);     /* set flag */
+    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1); /* set flag */
     free (tkn);
     break;
     /* time taken to serve the request, in microseconds */
@@ -1243,7 +1241,7 @@ parse_specifier (GLogItem *logitem, const char **str, const char *p, const char
     logitem->serve_time = serve_time;
 
     /* Determine if time-served data was stored on-disk. */
-    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1);     /* set flag */
+    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1); /* set flag */
     free (tkn);
     break;
     /* time taken to serve the request, in nanoseconds */
@@ -1262,7 +1260,7 @@ parse_specifier (GLogItem *logitem, const char **str, const char *p, const char
     logitem->serve_time = (serve_time > 0) ? serve_time / MILS : 0;
 
     /* Determine if time-served data was stored on-disk. */
-    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1);     /* set flag */
+    __sync_bool_compare_and_swap (&conf.serve_usecs, 0, 1); /* set flag */
     free (tkn);
     break;
     /* UMS: Krypto (TLS) "ECDHE-RSA-AES128-GCM-SHA256" */
@@ -1276,7 +1274,7 @@ parse_specifier (GLogItem *logitem, const char **str, const char *p, const char
 #if defined(HAVE_LIBSSL) && defined(HAVE_CIPHER_STD_NAME)
     {
       char *tmp = NULL;
-      for (tmp = tkn; isdigit (*tmp); tmp++);
+      for (tmp = tkn; isdigit ((unsigned char) *tmp); tmp++);
       if (!strlen (tmp))
         extract_tls_version_cipher (tkn, &logitem->tls_cypher, &logitem->tls_type);
       else
@@ -1435,8 +1433,8 @@ find_xff_host (GLogItem *logitem, const char **str, const char **p) {
     if (!(extract = parse_string (&(*str), pch, 1)))
       goto clean;
 
-    if (!(res = set_xff_host (logitem, extract, skips, 1)))
-      free (extract);
+    res = set_xff_host (logitem, extract, skips, 1);
+    free (extract);
     (*str)++;   /* move a char forward from the trailing delim */
   } else {
     res = set_xff_host (logitem, *str, skips, 0);
@@ -1514,7 +1512,7 @@ parse_format (GLogItem *logitem, const char *str, const char *lfmt) {
       if ((ret = parse_specifier (logitem, &str, p, end)))
         return ret;
       perc = 0;
-    } else if (perc && isspace (p[0])) {
+    } else if (perc && isspace ((unsigned char) p[0])) {
       return 1;
     } else {
       str++;
@@ -1564,8 +1562,7 @@ output_logerrors (void) {
     if (!glog->log_erridx)
       continue;
 
-    fprintf (stderr, "==%d== GoAccess - version %s - %s %s\n", pid, GO_VERSION, __DATE__,
-             __TIME__);
+    fprintf (stderr, "==%d== GoAccess - version %s - %s %s\n", pid, GO_VERSION, __DATE__, __TIME__);
     fprintf (stderr, "==%d== Config file: %s\n", pid, conf.iconfigfile ? : NO_CONFIG_FILE);
     fprintf (stderr, "==%d== https://goaccess.io - <hello@goaccess.io>\n", pid);
     fprintf (stderr, "==%d== Released under the MIT License.\n", pid);
@@ -1868,9 +1865,9 @@ static int
 atomic_lpts_update (GLog *glog, GLogItem *logitem) {
   int64_t oldts = 0, newts = 0;
   /* atomic update loop */
-  newts = mktime (&logitem->dt);        // Get timestamp from logitem->dt
+  newts = mktime (&logitem->dt); // Get timestamp from logitem->dt
   while (!__sync_bool_compare_and_swap (&glog->lp.ts, oldts, newts)) {
-    oldts = glog->lp.ts;        /* Reread glog->lp.ts if CAS failed */
+    oldts = glog->lp.ts; /* Reread glog->lp.ts if CAS failed */
     if (oldts >= newts) {
       break;    /* No need to update if oldts is already greater */
     }
@@ -1985,6 +1982,7 @@ read_line (GLog *glog, char *line, int *test, uint32_t *cnt, int dry_run) {
     uncount_invalid (glog);
     return NULL;
   }
+  glog->read++;
 
   return logitem;
 }
@@ -1999,8 +1997,7 @@ read_lines_thread (void *arg) {
     /* ensure we don't process more than we should when testing for log format,
      * else free chunk and stop processing threads */
     if (!job->test || (job->test && job->cnt < conf.num_tests))
-      job->logitems[i] =
-        read_line (job->glog, job->lines[i], &job->test, &job->cnt, job->dry_run);
+      job->logitems[i] = read_line (job->glog, job->lines[i], &job->test, &job->cnt, job->dry_run);
     else
       conf.stop_processing = 1;
 
@@ -2100,7 +2097,7 @@ static void
 read_lines_from_file (FILE *fp, GLog *glog, GJob jobs[2][conf.jobs], int b, char **s) {
   int k = 0;
 
-  for (k = 1; k < conf.jobs || (conf.jobs == 1 && k == 1); k++) {
+  for (k = 0; k < conf.jobs; k++) {
 #ifdef WITH_GETLINE
     while ((*s = fgetline (fp)) != NULL) {
       jobs[b][k].lines[jobs[b][k].p] = *s;
@@ -2108,7 +2105,6 @@ read_lines_from_file (FILE *fp, GLog *glog, GJob jobs[2][conf.jobs], int b, char
     while ((*s = fgets (jobs[b][k].lines[jobs[b][k].p], LINE_BUFFER, fp)) != NULL) {
 #endif
       glog->bytes += strlen (jobs[b][k].lines[jobs[b][k].p]);
-      glog->read++;
 
       if (++(jobs[b][k].p) >= conf.chunk_size)
         break;  // goto next chunk
@@ -2121,7 +2117,7 @@ static void
 process_lines (GJob jobs[2][conf.jobs], uint32_t *cnt, int *test, int b) {
   int k = 0;
 
-  for (k = 1; k < conf.jobs || (conf.jobs == 1 && k == 1); k++) {
+  for (k = 0; k < conf.jobs; k++) {
     process_lines_thread (&jobs[b][k]);
     *cnt += jobs[b][k].cnt;
     jobs[b][k].cnt = 0;
@@ -2181,9 +2177,9 @@ read_lines (FILE *fp, GLog *glog, int dry_run) {
     }
 
     if (conf.jobs == 1) {
-      read_lines_thread (&jobs[b][1]);
+      read_lines_thread (&jobs[b][0]);
     } else {
-      for (k = 1; k < conf.jobs; k++) {
+      for (k = 0; k < conf.jobs; k++) {
         jobs[b][k].running = 1;
         pthread_create (&threads[k], NULL, read_lines_thread, (void *) &jobs[b][k]);
       }
@@ -2199,10 +2195,12 @@ read_lines (FILE *fp, GLog *glog, int dry_run) {
     if (conf.jobs > 1)
       b = b ^ 1;
 
-    for (k = 1; k < conf.jobs; k++) {
-      if (jobs[b][k].running) {
-        pthread_join (threads[k], &status);
-        jobs[b][k].running = 0;
+    if (conf.jobs > 1) {
+      for (k = 0; k < conf.jobs; k++) {
+        if (jobs[b][k].running) {
+          pthread_join (threads[k], &status);
+          jobs[b][k].running = 0;
+        }
       }
     }
 
@@ -2220,12 +2218,12 @@ read_lines (FILE *fp, GLog *glog, int dry_run) {
     /* flip from block A/B to B/A */
     if (conf.jobs > 1)
       b = b ^ 1;
-  }     // while (1)
+  }             // while (1)
 
   /* After eof, process last data */
   for (b = 0; b < 2; b++) {
-    for (k = 1; k < conf.jobs; k++) {
-      if (jobs[b][k].running) {
+    for (k = 0; k < conf.jobs; k++) {
+      if (conf.jobs > 1 && jobs[b][k].running) {
         pthread_join (threads[k], &status);
         jobs[b][k].running = 0;
       }
@@ -2288,11 +2286,11 @@ persist_last_parse (GLog *glog) {
 
     memcpy (glog->lp.snippet, glog->snippet, glog->snippetlen);
 
-    ht_insert_last_parse (glog->props.inode, glog->lp);
+    ht_insert_last_parse (glog->props.inode, &glog->lp);
   }
   /* probably from a pipe */
   else if (!glog->props.inode) {
-    ht_insert_last_parse (0, glog->lp);
+    ht_insert_last_parse (0, &glog->lp);
   }
 }
 
