@@ -60,7 +60,7 @@
 pthread_mutex_t tz_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 /* HTTP status codes categories */
-static const char *code_type[] = {
+static const char *const code_type[] = {
   STATUS_CODE_0XX,
   STATUS_CODE_1XX,
   STATUS_CODE_2XX,
@@ -70,7 +70,7 @@ static const char *code_type[] = {
 };
 
 /* HTTP status codes */
-static const char *codes[1000] = {
+static const char *const codes[600] = {
   [0] = STATUS_CODE_0,
   [100] = STATUS_CODE_100, STATUS_CODE_101,
   [200] = STATUS_CODE_200, STATUS_CODE_201, STATUS_CODE_202, STATUS_CODE_203, STATUS_CODE_204,
@@ -101,8 +101,7 @@ static const char *codes[1000] = {
   [530] = STATUS_CODE_530,
   [540] = STATUS_CODE_540,
   [561] = STATUS_CODE_561,
-  [590] = STATUS_CODE_598, STATUS_CODE_599,
-  [999] = NULL
+  [598] = STATUS_CODE_598, STATUS_CODE_599,
 };
 
 /* Return part of a string
@@ -192,7 +191,7 @@ djb2 (const unsigned char *str) {
   int c;
 
   while ((c = *str++))
-    hash = ((hash << 5) + hash) + c;    /* hash * 33 + c */
+    hash = ((hash << 5) + hash) + c; /* hash * 33 + c */
 
   return hash;
 }
@@ -232,14 +231,14 @@ wc_match (const char *wc, char *str) {
  */
 static char *
 extract_hostname (const char *url) {
-  char *start, *end;
+  const char *start, *end;
   char *hostname = NULL;
 
   start = strstr (url, "://");
   if (start != NULL) {
     start += 3;
   } else {
-    start = (char *) url;
+    start = url;
   }
 
   end = strchr (start, '/');
@@ -582,8 +581,7 @@ set_tz (void) {
   snprintf (tz, TZ_NAME_LEN, "TZ=%s", conf.tz_name);
   if ((putenv (tz)) != 0) {
     int old_errno = errno;
-    LOG_DEBUG (("Can't set TZ env variable %s: %s: %d\n", tz, strerror (old_errno),
-                old_errno));
+    LOG_DEBUG (("Can't set TZ env variable %s: %s: %d\n", tz, strerror (old_errno), old_errno));
     goto release;
   }
 
@@ -814,7 +812,7 @@ file_size (const char *filename) {
  * On success, the status code type/category is returned. */
 const char *
 verify_status_code_type (int code) {
-  if (code >= 0 && code <= 599 && code_type[code / 100] == NULL)
+  if (code < 0 || code > 599 || code_type[code / 100] == NULL)
     return "Unknown";
 
   return code_type[code / 100];
@@ -827,7 +825,7 @@ verify_status_code_type (int code) {
  * On success, the status code is returned. */
 const char *
 verify_status_code (int code) {
-  if (code >= 0 && code <= 599 && code_type[code / 100] == NULL && codes[code] == NULL)
+  if (code < 0 || code > 599 || code_type[code / 100] == NULL || codes[code] == NULL)
     return "Unknown";
 
   return codes[code];
@@ -860,7 +858,7 @@ char *
 ltrim (char *s) {
   char *begin = s;
 
-  while (isspace (*begin))
+  while (isspace ((unsigned char) *begin))
     ++begin;
   memmove (s, begin, strlen (begin) + 1);
 
@@ -875,7 +873,7 @@ char *
 rtrim (char *s) {
   char *end = s + strlen (s);
 
-  while ((end != s) && isspace (*(end - 1)))
+  while ((end != s) && isspace ((unsigned char) *(end - 1)))
     --end;
   *end = '\0';
 
@@ -1092,7 +1090,7 @@ strtoupper (char *str) {
     return str;
 
   while (*p != '\0') {
-    *p = toupper (*p);
+    *p = toupper ((unsigned char) *p);
     p++;
   }
 
